@@ -3,3 +3,6 @@ def ls_users(recipe):
 
 def ls_groups(recipe):
     return "cut -d: -f1 /etc/group | sort"
+
+def ls_cpus(recipe):
+    return "cat /proc/cpuinfo | awk '/^processor/{print $3}'"
